pub struct CoinMetadata {
pub address: Address,
pub decimals: Option<i32>,
pub description: Option<String>,
pub icon_url: Option<String>,
pub name: Option<String>,
pub symbol: Option<String>,
pub supply: Option<BigInt>,
pub version: u64,
}Expand description
The coin metadata associated with the given coin type.
Fields
address: AddressThe CoinMetadata object ID.
decimals: Option<i32>The number of decimal places used to represent the token.
description: Option<String>Optional description of the token, provided by the creator of the token.
icon_url: Option<String>Icon URL of the coin.
name: Option<String>Full, official name of the token.
symbol: Option<String>The token’s identifying abbreviation.
supply: Option<BigInt>The overall quantity of tokens that will be issued.
version: u64Version of the token.