pub struct ServiceConfig {Show 13 fields
pub default_page_size: i32,
pub enabled_features: Vec<Feature>,
pub max_move_value_depth: i32,
pub max_output_nodes: i32,
pub max_page_size: i32,
pub max_query_depth: i32,
pub max_query_nodes: i32,
pub max_query_payload_size: i32,
pub max_type_argument_depth: i32,
pub max_type_argument_width: i32,
pub max_type_nodes: i32,
pub mutation_timeout_ms: i32,
pub request_timeout_ms: i32,
}Fields
default_page_size: i32Default number of elements allowed on a single page of a connection.
enabled_features: Vec<Feature>List of all features that are enabled on this RPC service.
max_move_value_depth: i32Maximum estimated cost of a database query used to serve a GraphQL request. This is measured in the same units that the database uses in EXPLAIN queries. Maximum nesting allowed in struct fields when calculating the layout of a single Move Type.
max_output_nodes: i32The maximum number of output nodes in a GraphQL response. Non-connection nodes have a count of 1, while connection nodes are counted as the specified ‘first’ or ‘last’ number of items, or the default_page_size as set by the server if those arguments are not set. Counts accumulate multiplicatively down the query tree. For example, if a query starts with a connection of first: 10 and has a field to a connection with last: 20, the count at the second level would be 200 nodes. This is then summed to the count of 10 nodes at the first level, for a total of 210 nodes.
max_page_size: i32Maximum number of elements allowed on a single page of a connection.
max_query_depth: i32The maximum depth a GraphQL query can be to be accepted by this service.
max_query_nodes: i32The maximum number of nodes (field names) the service will accept in a single query.
max_query_payload_size: i32Maximum length of a query payload string.
max_type_argument_depth: i32Maximum nesting allowed in type arguments in Move Types resolved by this service.
max_type_argument_width: i32Maximum number of type arguments passed into a generic instantiation of a Move Type resolved by this service.
max_type_nodes: i32Maximum number of structs that need to be processed when calculating the layout of a single Move Type.
mutation_timeout_ms: i32Maximum time in milliseconds spent waiting for a response from fullnode after issuing a a transaction to execute. Note that the transaction may still succeed even in the case of a timeout. Transactions are idempotent, so a transaction that times out should be resubmitted until the network returns a definite response (success or failure, not timeout).
request_timeout_ms: i32Maximum time in milliseconds that will be spent to serve one query request.